Contributor's Guide
===================

Getting Started
---------------

If you are new to Magnum, this section contains information that should help
you get started as a developer working on the project or contributing to the
project.

.. toctree::
  :maxdepth: 1

  Developer Contribution Guide <contributing>
  Setting Up Your Development Environment <quickstart>
  Running Tempest Tests <functional-test>
  Developer Troubleshooting Guide <troubleshooting>

There are some other important documents also that helps new contributors to
contribute effectively towards code standards to the project.

.. toctree::
  :maxdepth: 1

  Writing a Release Note <reno>
  Adding a New API Method <api-microversion>
  Changing Magnum DB Objects <objects>
  api-microversion-history
  policies
